@@ -10,6 +10,7 @@ use crate::card::Card;
 use crate::scores::Scores;
 use crate::Opts;
 
+/// A list of durations which cards will be waiting by.
 pub static DURATIONS: [Duration; 5] = [
     Duration::from_secs(0),                     // Instant
     Duration::from_secs(60 * 60 * 24),          // Daily
@@ -18,6 +19,7 @@ pub static DURATIONS: [Duration; 5] = [
     Duration::from_secs(60 * 60 * 24 * 28 * 2), // Bimonthly
 ];
 
+/// A convenience type representing an index of [`App::cards`]
 pub type CardIdx = usize;
 
 /// App holds the state of the application
@@ -29,7 +31,11 @@ pub struct App {
     playable_cards: Vec<CardIdx>,
     scores: HashMap<CardIdx, usize>,
     dues: HashMap<CardIdx, DateTime<Utc>>,
+    /// This determines whether the card should show the
+    /// question or the answer.
     pub flipped: bool,
+    /// The (command line) options of the [`App`] to determine
+    /// how it willl run.
     pub opts: Opts,
 }
 
@@ -134,14 +140,20 @@ impl App {
         }
     }
 
+    /// Gets the current card from the app.
     pub fn card(&self) -> &Card {
         &self.cards[self.card]
     }
 
+    /// Gets the score of the current card from the app.
     pub fn card_score(&self) -> usize {
         *self.scores.get(&self.card).unwrap_or(&0)
     }
 
+    /// Resets the duration of the current card.
+    ///
+    /// This will index [`DURATIONS`] and work out from that
+    /// how far forth it should be due.
     pub fn reset_current_card_duration(&mut self) {
         let score = self.card_score().min(DURATIONS.len());
         let duration = DURATIONS[score];
@@ -152,6 +164,9 @@ impl App {
         self.dues.insert(self.card, val);
     }
 
+    /// Changes the score of the current card.
+    ///
+    /// A card can not have a negative score.
     pub fn change_current_card_score(&mut self, val: isize) {
         let entry = self.scores.entry(self.card).or_default();
         if val > 0 {
@@ -162,6 +177,8 @@ impl App {
         self.reset_current_card_duration();
     }
 
+    /// Determines if the current card still should be played
+    /// or if its due date has expired.
     pub fn current_card_is_finished(&self, card: usize) -> bool {
         let now = Utc::now();
 
@@ -172,6 +189,7 @@ impl App {
         }
     }
 
+    /// Gets how many cards still need to be played.
     pub fn unfinished_count(&self) -> usize {
         let mut count = 0;
 
@@ -184,6 +202,7 @@ impl App {
         count
     }
 
+    /// Writes the scores to the file specified in [`App::opts`].
     pub fn write_scores(&self) -> io::Result<()> {
         if !self.opts.nowrite {
             let new_path = self.opts.input.with_extension("score.json");
@@ -196,30 +215,32 @@ impl App {
         Ok(())
     }
 
+    /// Adds a [`flashed::Scores`] into an [`App`]
+    pub fn add_scores(&mut self, scores: Scores) {
+        for (card, score) in scores.scores {
+            let pos = self.cards().iter().position(|x| x == card.as_ref());
+            if let Some(pos) = pos {
+                self.scores.insert(pos, score);
+            }
+        }
+
+        for (card, due) in scores.dues {
+            let pos = self.cards().iter().position(|x| x == card.as_ref());
+            if let Some(pos) = pos {
+                self.dues.insert(pos, due);
+            }
+        }
+
+        self.retain_undue();
+    }
+
+    /// Reads the scores from the file in [`App::opts`]
     pub fn read_scores(&mut self) -> io::Result<()> {
         let new_path = self.opts.input.with_extension("score.json");
         match File::open(new_path) {
             Ok(file) => {
                 let scores: Scores<'_> = serde_json::from_reader(&file)?;
-
-                for (card, score) in scores.scores {
-                    let pos =
-                        self.cards().iter().position(|x| x == card.as_ref());
-                    if let Some(pos) = pos {
-                        self.scores.insert(pos, score);
-                    }
-                }
-
-                for (card, due) in scores.dues {
-                    let pos =
-                        self.cards().iter().position(|x| x == card.as_ref());
-                    if let Some(pos) = pos {
-                        self.dues.insert(pos, due);
-                    }
-                }
-
-                self.retain_undue();
-
+                self.add_scores(scores);
                 Ok(())
             }
             Err(e) if e.kind() == io::ErrorKind::NotFound => Ok(()),
